@@ -21,19 +21,13 @@
 #include <clens.h>
 #endif
 
-#include <event2/event.h>
-
-#if !defined(evutil_socket_t)
-#define evutil_socket_t int
-#endif
-
-#include <openssl/ssl.h>
+#include <assl_socket.h>
 
 /* versioning */
 #define ASSL_STRINGIFY(x)	#x
 #define ASSL_STR(x)		ASSL_STRINGIFY(x)
 #define ASSL_VERSION_MAJOR	1
-#define ASSL_VERSION_MINOR	0
+#define ASSL_VERSION_MINOR	2
 #define ASSL_VERSION_PATCH	0
 #define ASSL_VERSION		ASSL_STR(ASSL_VERSION_MAJOR) "." \
 				ASSL_STR(ASSL_VERSION_MINOR) "." \
@@ -53,6 +47,11 @@ void		 assl_version(int *major, int *minor, int *patch);
 #define ASSL_F_LOWDELAY		(1<<6)
 #define ASSL_F_THROUGHPUT	(1<<7)
 #define ASSL_F_BLOCK		(0)
+/* assl_alloc_context_v2 only flags */
+#define ASSL_F_TLS1_2		(1<<28)
+#define ASSL_F_TLS1_1		(1<<29)
+#define ASSL_F_TLS1		(1<<30)
+#define ASSL_F_SSLV3		(1<<31)
 
 #define ASSL_GF_IGNORE_SELF_SIGNED	(1<<0)
 #define ASSL_GF_IGNORE_EXPIRED		(1<<1)
@@ -66,15 +65,21 @@ enum assl_method {
 	ASSL_M_ALL,
 	ASSL_M_ALL_CLIENT,
 	ASSL_M_ALL_SERVER,
-	ASSL_M_SSLV2,
-	ASSL_M_SSLV2_CLIENT,
-	ASSL_M_SSLV2_SERVER,
+	ASSL_M_SSLV2_DEPRECATED,
+	ASSL_M_SSLV2_CLIENT_DEPRECATED,
+	ASSL_M_SSLV2_SERVER_DEPRECATED,
 	ASSL_M_SSLV3,
 	ASSL_M_SSLV3_CLIENT,
 	ASSL_M_SSLV3_SERVER,
 	ASSL_M_TLSV1,
 	ASSL_M_TLSV1_CLIENT,
-	ASSL_M_TLSV1_SERVER
+	ASSL_M_TLSV1_SERVER,
+	ASSL_M_TLSV1_1,
+	ASSL_M_TLSV1_1_CLIENT,
+	ASSL_M_TLSV1_1_SERVER,
+	ASSL_M_TLSV1_2,
+	ASSL_M_TLSV1_2_CLIENT,
+	ASSL_M_TLSV1_2_SERVER,
 };
 
 struct assl_context {
@@ -86,6 +91,7 @@ struct assl_context {
 	SSL_SESSION		*as_ssl_session;
 	int			as_sock;
 	BIO			*as_sbio;
+	DH			*as_dh;		/* dh param */
 
 	/* memory certificates */
 	void			*as_token;
@@ -100,10 +106,7 @@ struct assl_context {
 	X509			*as_peer;
 	int			as_bits;	/* -1 invalid */
 	char			as_protocol[128];
-
-	/* event */
-	struct event		*as_ev_rd;
-	struct event		*as_ev_wr;
+	int			as_curve;	/* named curve */
 
 	/* peer IP */
 	char			*as_peername;
@@ -119,29 +122,14 @@ int			assl_load_file_certs(struct assl_context *,
 			    const char *, const char *, const char *);
 int			assl_connect(struct assl_context *, const char *,
 				const char *, int);
-int			assl_event_connect(struct assl_context *, const char *,
-			    const char *, int, struct event_base *,
-			    void (*rd_cb)(evutil_socket_t, short, void *),
-			    void (*wr_cb)(evutil_socket_t, short, void *),
-			    void *);
 int			assl_serve(const char *, const char *, int,
 			    void (*)(int), void (*)(void));
-struct assl_serve_ctx	*assl_event_serve(const char *, const char *, int flags,
-			    struct event_base *, void (*)(int, short, void *),
-			    void *);
-void			assl_event_serve_stop(struct assl_serve_ctx *);
 int			assl_accept(struct assl_context *, int);
-int			assl_event_accept(struct assl_context *,
-			    struct event_base *, int,
-			    void (*)(evutil_socket_t, short, void *),
-			    void (*)(evutil_socket_t, short, void *),
-			    void *);
 __dead void		assl_fatalx(const char *, ...);
 void			assl_warnx(const char *, ...);
 ssize_t			assl_read(struct assl_context *, void *, size_t);
 ssize_t			assl_write(struct assl_context *, void *, size_t);
 int			assl_close(struct assl_context *);
-int			assl_event_close(struct assl_context *);
 int			assl_poll(struct assl_context *, int, short, short *);
 ssize_t			assl_read_timeout(struct assl_context *, void *, size_t,
 			    unsigned);
@@ -154,9 +142,12 @@ void			*assl_load_file_certs_to_mem(const char *, const char *,
 			    const char *);
 int			assl_use_mem_certs(struct assl_context *, void *);
 int			assl_destroy_mem_certs(void *);
-void			assl_event_enable_write(struct assl_context *);
-void			assl_event_disable_write(struct assl_context *);
 void			assl_set_log_callback(void (*)(int, const char *));
+int			assl_fd(struct assl_context *);
+
+/* new api */
+#define ASSL_ARG_NAMEDCURVE	"named_curve="
+struct assl_context	*assl_alloc_context_v2(int, char *[]);
 
 #ifndef INFTIM
 #define INFTIM		(-1)
