@@ -25,7 +25,7 @@ serve_callback(int s)
 	char			buf[65536 * 10];
 	ssize_t			rd;
 
-	c = assl_alloc_context(ASSL_M_TLSV1_SERVER, 0);
+	c = assl_alloc_context(ASSL_M_ALL, 0);
 	if (c == NULL)
 		assl_fatalx("assl_alloc_context");
 
@@ -35,6 +35,7 @@ serve_callback(int s)
 
 	if (assl_accept(c, s))
 		assl_fatalx("assl_accept");
+	printf("CIPHER: %s\n", c->as_protocol);
 
 	rd = assl_read(c, buf, sizeof buf);
 	if (rd == -1)
